package
module
Version:
v0.0.3
Opens a new window with list of versions in this module.
Published: Sep 27, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Point

The Point package provides external package adapter for some architecture.
Documentation
¶
Package point provides some external package adapter form some architecture.
Usage:
import github.com/carlsiry/point
func main() {
point.New()
}
Other tips.
Source Files
¶
Directories
¶
pkg
|
|
|
|
|
|
|
|
sftp
Package sftp packaging some api of "github.com/pkg/sftp".
|
Package sftp packaging some api of "github.com/pkg/sftp". |
|
|
|
Click to show internal directories.
Click to hide internal directories.